@@ -325,8 +325,38 @@ void MainWindow::on_pushButton_clicked()
 
 }
 
+void MainWindow::clean()
+{
+QString directory_path = "/opt/theme-customizer/backups/";
+
+QDirIterator directory_walker(directory_path, QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
+
+while(directory_walker.hasNext())
+{
+      directory_walker.next();
+
+     QString filee_orig = directory_walker.filePath();
+     QString filee = filee_orig;
+     filee.remove("/opt/theme-customizer/backups");
+     QDir backupfile(filee_orig);
+     QFileInfo info = filee_orig;
+
+     if (!QFile::exists(filee)) {
+    //     QMaemo5InformationBox::information(this, "Alkuperist: " + filee + " ei lydy, poistetaan: " + filee_orig, QMaemo5InformationBox::NoTimeout);
+         if (info.isDir()) {
+             backupfile.rmdir(filee_orig);
+         } else if (info.isFile()) {
+             QFile::remove(filee_orig);
+         }
+
+     }
+
+}
+}
+
 void MainWindow::runscript(QString command)
 {
+
     QString varattu;
     varattu = "Theme Customizer";
     progress.setWindowModality(Qt::WindowModal);
@@ -390,6 +420,8 @@ void MainWindow::runscript(QString command)
     muoks1->start("/sbin/launchcustomizer", systemcommand);
     muoks1->waitForFinished();
     progress.setValue(10);
+    clean();
+    clean();
 
 //        QMaemo5InformationBox::information(this, tr("Setting up font family..."), 1);
     progress.setLabelText(tr("Setting up font family..."));
@@ -511,14 +543,13 @@ void MainWindow::runscript(QString command)
     progress.setValue(86);
     progress.setValue(88);
 
+
     if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
 
         progress.setLabelText(tr("Restarting services..."));
-        QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."), QMaemo5InformationBox::DefaultTimeout);
-        system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
-        sleep(2);
-        system("killall hildon-status-menu");
-        sleep(2);
+        progress.setValue(90);
+  //      sleep(1);
+  //      QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."), QMaemo5InformationBox::DefaultTimeout);
         system("ps ax | grep -v grep | grep osso-abook-home-applet > /dev/null && killall osso-abook-home-applet && sleep 2 &&  ps ax | grep -v grep | grep osso-abook-home-applet || /usr/sbin/dsmetool -t /usr/bin/osso-abook-home-applet");
         sleep(2);
         system("killall systemui");
@@ -526,14 +557,16 @@ void MainWindow::runscript(QString command)
         system("killall browser browserd");
         sleep(2);
         system("killall rtcom-messaging-ui");
-        progress.setValue(99);
+        progress.setValue(95);
         sleep(2);
         system("killall rtcom-call-ui");
         sleep(2);
-        system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
-        sleep(4);
-        system("killall hildon-desktop");
-        sleep(2);
+        systemcommand.clear();
+        systemcommand << "restartservices";
+	QProcess *muoks8 = new QProcess(this);
+	muoks8->start("/sbin/launchcustomizer", systemcommand);
+	muoks8->waitForFinished();
+	sleep(2);
         system("killall theme-customizer");
 
     } else {
@@ -767,7 +800,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-55<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-56<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
