@@ -176,8 +176,20 @@
         <translation>必须给主题命名.</translation>
     </message>
     <message>
-        <source> already exists!</source>
-        <translation>已存在!</translation>
+        <source>Overwrite existing theme?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Theme with this name already exists, do you want to overwrite it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Theme </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> already exists and cannot be overwritten!</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Do you want to restore all original theme files?</source>
@@ -315,10 +327,6 @@
         <source>Theme Customizer - restore files</source>
         <translation>Theme Customizer - 恢复文件</translation>
     </message>
-    <message>
-        <source>Folder </source>
-        <translation>文件夹</translation>
-    </message>
     <message>
         <source>Change backgrounds</source>
         <translation>更改背景</translation>
